import React, { useEffect, useState } from "react";
import { Box, Button, Typography, TextField } from "@mui/material";
import AddEditRoleModal from "../../components/AddEditRoleModal";
import PermissionsTable from "../../pages/PermissionTable";
import { useForm } from "react-hook-form";
import CustomTable, { Column } from "../../components/CustomTable";
import { useDispatch, useSelector } from "react-redux";
import { createRole, roleList } from "../../redux/slices/roleSlice";
import { AppDispatch, RootState } from "../../redux/store/store";
import { useNavigate } from "react-router-dom";

export default function RoleList() {
	const [modalOpen, setModalOpen] = useState(false);
	const { reset } = useForm();

	const [deleteModal, setDeleteModal] = React.useState<boolean>(false);
	const [viewModal, setViewModal] = React.useState<boolean>(false);
	const [rowData, setRowData] = React.useState<any | null>(null);
	const [searchTerm, setSearchTerm] = useState("");
	const [showPermissions, setShowPermissions] = useState(false);

	const dispatch = useDispatch<AppDispatch>();
	const navigate = useNavigate();

	const roles = useSelector((state: RootState) => state.roleReducer.roles);

	useEffect(() => {
		dispatch(roleList());
	}, [dispatch]);

	const handleClickOpen = () => {
		navigate("/panel/permissions");// Navigate to the correct route
	};
	
	const handleCloseModal = () => {
		setModalOpen(false);
		setRowData(null);
		reset();
	};

	const handleCreate = async (data: {
		name: string;
		resource: {
			moduleName: string;
			moduleId: string;
			permissions: string[];
		}[];
	}) => {
		try {
			await dispatch(createRole(data));
			await dispatch(roleList()); // Refresh the list after creation
			handleCloseModal();
		} catch (error) {
			console.error("Creation failed", error);
		}
	};

	const categoryColumns: Column[] = [
		{ id: "srno", label: "Sr No" },
		{ id: "name", label: "Name" },
		{ id: "status", label: "Status" },
		{ id: "action", label: "Action", align: "center" },
	];

	const categoryRows = roles?.length
		? roles?.map(function (
			role: {
				id: string;
				name: string;
				status: string;
			},
			index: number
		) {
			return {
				id: role?.id,
				srno: index + 1,
				name: role?.name,
				status: role?.status,
			};
		})
		: [];

	console.log("Category Rows:", categoryRows);

	return (
		<>
			{/* <Box
				sx={{
					width: "100%",
					backgroundColor: "#E3F2FD", // Light sky blue color
					p: 2,
					display: "flex",
					justifyContent: "space-between",
					alignItems: "center",
					mb: 2,
			}}
		>
			<Typography variant="h6" fontWeight={600}>Roles & Permission</Typography>
			<Typography variant="body1">Dashboard</Typography>
		</Box> */}

			<Box
				sx={{
					width: "100%",
					display: "flex",
					justifyContent: "space-between",
					alignItems: "center",
					mb: 2,
			}}
		>
			<TextField
				variant="outlined"
				size="small"
				placeholder="Search..."
				value={searchTerm}
				onChange={(e) => setSearchTerm(e.target.value)}
				sx={{ width: "30%" }}
			/>
			<Button
				variant="contained"
				size="small"
				onClick={handleClickOpen}
			>
				Add Role
			</Button>
		</Box>

			{showPermissions ? (
				<PermissionsTable />
			) : (
				<CustomTable
					columns={categoryColumns}
					rows={categoryRows}
					setDeleteModal={setDeleteModal}
					deleteModal={deleteModal}
					setViewModal={setViewModal}
					viewModal={viewModal}
					setRowData={setRowData}
					setModalOpen={setModalOpen}
				/>
			)}

			<AddEditRoleModal
				open={modalOpen}
				handleClose={handleCloseModal}
				handleCreate={handleCreate}
				editRow={rowData}
			/>
		</>
	);
}
